@@ -7,9 +7,9 @@ use vars qw($m_hrActions $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Actions::EXPORT = qw(loadActions saveActions $m_hrActions);
 use MySQL::Admin::Config;
 @MySQL::Admin::Actions::ISA     = qw( Exporter MySQL::Admin::Config);
-$MySQL::Admin::Actions::VERSION = '1.14';
-$DefaultClass  = 'MySQL::Admin::Actions' unless defined $MySQL::Admin::Actions::DefaultClass;
-$defaultconfig = '%CONFIG%';
+$MySQL::Admin::Actions::VERSION = '1.15';
+$DefaultClass                   = 'MySQL::Admin::Actions' unless defined $MySQL::Admin::Actions::DefaultClass;
+$defaultconfig                  = '%CONFIG%';
 
 =head1 NAME
 
@@ -54,30 +54,30 @@ loadActions() saveActions() $m_hrActions
 =cut
 
 sub new {
-    my ($class, @initializer) = @_;
+    my ( $class, @initializer ) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
     return $self;
-}
+} ## end sub new
 
 =head2 loadActions
 
 =cut
 
 sub loadActions {
-    my ($self, @p) = getSelf(@_);
-    my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) { do $do; }
-}
+    my ( $self, @p ) = getSelf(@_);
+    my $do = ( defined $p[0] ) ? $p[0] : $defaultconfig;
+    if ( -e $do ) { do $do; }
+} ## end sub loadActions
 
 =head2 saveActions
 
 =cut
 
 sub saveActions {
-    my ($self, @p) = getSelf(@_);
-    $self->SUPER::saveConfig(@p, $m_hrActions, 'actions');
-}
+    my ( $self, @p ) = getSelf(@_);
+    $self->SUPER::saveConfig( @p, $m_hrActions, 'actions' );
+} ## end sub saveActions
 
 =head1 Private
 
@@ -86,13 +86,14 @@ sub saveActions {
 =cut
 
 sub getSelf {
-    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Actions');
-    return (defined($_[0])
-              && (ref($_[0]) eq 'MySQL::Admin::Actions'
-                  || UNIVERSAL::isa($_[0], 'MySQL::Admin::Actions')))
+    return @_ if defined( $_[0] ) && ( !ref( $_[0] ) ) && ( $_[0] eq 'MySQL::Admin::Actions' );
+    return (
+        defined( $_[0] ) && ( ref( $_[0] ) eq 'MySQL::Admin::Actions'
+            || UNIVERSAL::isa( $_[0], 'MySQL::Admin::Actions' ) )
+      )
       ? @_
-      : ($MySQL::Admin::Actions::DefaultClass->new, @_);
-}
+      : ( $MySQL::Admin::Actions::DefaultClass->new, @_ );
+} ## end sub getSelf
 
 =head2 see Also
 
@@ -115,5 +116,4 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Lesser General Public License for more details.
 
 =cut
-
 1;
