@@ -7,9 +7,9 @@ use vars qw( $session $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Session::EXPORT = qw(loadSession saveSession $session);
 use MySQL::Admin::Config;
 @MySQL::Admin::Session::ISA     = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Session::VERSION = '1.14';
-$DefaultClass  = 'MySQL::Admin::Session' unless defined $MySQL::Admin::Session::DefaultClass;
-$defaultconfig = '%CONFIG%';
+$MySQL::Admin::Session::VERSION = '1.15';
+$DefaultClass                   = 'MySQL::Admin::Session' unless defined $MySQL::Admin::Session::DefaultClass;
+$defaultconfig                  = '%CONFIG%';
 
 =head1 NAME
 
@@ -34,11 +34,11 @@ loadConfig() saveSession() $session
 =cut
 
 sub new {
-    my ($class, @initializer) = @_;
+    my ( $class, @initializer ) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
     return $self;
-}
+} ## end sub new
 
 =head2 loadSession
 
@@ -47,20 +47,20 @@ load session via do from disk.
 =cut
 
 sub loadSession {
-    my ($self, @p) = getSelf(@_);
-    my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) { do $do; }
-}
+    my ( $self, @p ) = getSelf(@_);
+    my $do = ( defined $p[0] ) ? $p[0] : $defaultconfig;
+    if ( -e $do ) { do $do; }
+} ## end sub loadSession
 
 =head2 saveSession
 
 =cut
 
 sub saveSession {
-    my ($self, @p) = getSelf(@_);
+    my ( $self, @p ) = getSelf(@_);
     my $l = defined $p[0] ? $p[0] : $defaultconfig;
-    $self->SUPER::saveConfig($l, $session, 'session');
-}
+    $self->SUPER::saveConfig( $l, $session, 'session' );
+} ## end sub saveSession
 
 =head1 Private
 
@@ -69,13 +69,14 @@ sub saveSession {
 =cut
 
 sub getSelf {
-    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Session');
-    return (defined($_[0])
-              && (ref($_[0]) eq 'MySQL::Admin::Session'
-                  || UNIVERSAL::isa($_[0], 'MySQL::Admin::Session')))
+    return @_ if defined( $_[0] ) && ( !ref( $_[0] ) ) && ( $_[0] eq 'MySQL::Admin::Session' );
+    return (
+        defined( $_[0] ) && ( ref( $_[0] ) eq 'MySQL::Admin::Session'
+            || UNIVERSAL::isa( $_[0], 'MySQL::Admin::Session' ) )
+      )
       ? @_
-      : ($MySQL::Admin::Session::DefaultClass->new, @_);
-}
+      : ( $MySQL::Admin::Session::DefaultClass->new, @_ );
+} ## end sub getSelf
 
 =head1 AUTHOR
 
@@ -98,5 +99,4 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Lesser General Public License for more details.
 
 =cut
-
 1;
