@@ -7,9 +7,9 @@ use vars qw($m_hrSettings $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Settings::EXPORT = qw(loadSettings saveSettings $m_hrSettings);
 use MySQL::Admin::Config;
 @ISA                             = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Settings::VERSION = '1.14';
-$DefaultClass  = 'MySQL::Admin::Settings' unless defined $MySQL::Admin::Settings::DefaultClass;
-$defaultconfig = '%CONFIG%';
+$MySQL::Admin::Settings::VERSION = '1.15';
+$DefaultClass                    = 'MySQL::Admin::Settings' unless defined $MySQL::Admin::Settings::DefaultClass;
+$defaultconfig                   = '%CONFIG%';
 
 =head1 NAME
 
@@ -47,31 +47,31 @@ loadSettings() saveSettings() $m_hrSettings
 =cut
 
 sub new {
-    my ($class, @initializer) = @_;
+    my ( $class, @initializer ) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
     return $self;
-}
+} ## end sub new
 
 =head2 loadSettings()
 
 =cut
 
 sub loadSettings {
-    my ($self, @p) = getSelf(@_);
-    my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) { do $do; }
-}
+    my ( $self, @p ) = getSelf(@_);
+    my $do = ( defined $p[0] ) ? $p[0] : $defaultconfig;
+    if ( -e $do ) { do $do; }
+} ## end sub loadSettings
 
 =head2 saveSettings()
 
 =cut
 
 sub saveSettings {
-    my ($self, @p) = getSelf(@_);
+    my ( $self, @p ) = getSelf(@_);
     my $l = defined $p[0] ? $p[0] : $defaultconfig;
-    $self->SUPER::saveConfig($l, $m_hrSettings, 'm_hrSettings');
-}
+    $self->SUPER::saveConfig( $l, $m_hrSettings, 'm_hrSettings' );
+} ## end sub saveSettings
 
 =head1 Private
 
@@ -80,15 +80,14 @@ sub saveSettings {
 =cut
 
 sub getSelf {
-    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Settings');
+    return @_ if defined( $_[0] ) && ( !ref( $_[0] ) ) && ( $_[0] eq 'MySQL::Admin::Settings' );
     return (
-            defined($_[0])
-              && (ref($_[0]) eq 'MySQL::Admin::Settings'
-                  || UNIVERSAL::isa($_[0], 'MySQL::Admin::Settings'))
-           )
+        defined( $_[0] ) && ( ref( $_[0] ) eq 'MySQL::Admin::Settings'
+            || UNIVERSAL::isa( $_[0], 'MySQL::Admin::Settings' ) )
+      )
       ? @_
-      : ($MySQL::Admin::Settings::DefaultClass->new, @_);
-}
+      : ( $MySQL::Admin::Settings::DefaultClass->new, @_ );
+} ## end sub getSelf
 
 =head2 see Also
 
@@ -111,5 +110,4 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Lesser General Public License for more details.
 
 =cut
-
 1;
