@@ -7,9 +7,9 @@ use vars qw($ACCEPT_LANGUAGE $lang $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Translate::EXPORT = qw(loadTranslate saveTranslate $lang);
 use MySQL::Admin::Config;
 @ISA                              = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Translate::VERSION = '1.14';
-$DefaultClass  = 'MySQL::Admin::Translate' unless defined $MySQL::Admin::Translate::DefaultClass;
-$defaultconfig = '%CONFIG%';
+$MySQL::Admin::Translate::VERSION = '1.15';
+$DefaultClass                     = 'MySQL::Admin::Translate' unless defined $MySQL::Admin::Translate::DefaultClass;
+$defaultconfig                    = '%CONFIG%';
 
 =head1 NAME
 
@@ -42,31 +42,31 @@ loadTranslate() saveTranslate() $lang
 =cut
 
 sub new {
-    my ($class, @initializer) = @_;
+    my ( $class, @initializer ) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
     return $self;
-}
+} ## end sub new
 
 =head2 loadTranslate()
 
 =cut
 
 sub loadTranslate {
-    my ($self, @p) = getSelf(@_);
-    my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) { do $do; }
-}
+    my ( $self, @p ) = getSelf(@_);
+    my $do = ( defined $p[0] ) ? $p[0] : $defaultconfig;
+    if ( -e $do ) { do $do; }
+} ## end sub loadTranslate
 
 =head2  saveTranslate()
 
 =cut
 
 sub saveTranslate {
-    my ($self, @p) = getSelf(@_);
+    my ( $self, @p ) = getSelf(@_);
     my $l = defined $p[0] ? $p[0] : $defaultconfig;
-    $self->SUPER::saveConfig($l, $lang, 'lang');
-}
+    $self->SUPER::saveConfig( $l, $lang, 'lang' );
+} ## end sub saveTranslate
 
 =head1 Private
 
@@ -75,15 +75,14 @@ sub saveTranslate {
 =cut
 
 sub getSelf {
-    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Translate');
+    return @_ if defined( $_[0] ) && ( !ref( $_[0] ) ) && ( $_[0] eq 'MySQL::Admin::Translate' );
     return (
-            defined($_[0])
-              && (ref($_[0]) eq 'MySQL::Admin::Translate'
-                  || UNIVERSAL::isa($_[0], 'MySQL::Admin::Translate'))
-           )
+        defined( $_[0] ) && ( ref( $_[0] ) eq 'MySQL::Admin::Translate'
+            || UNIVERSAL::isa( $_[0], 'MySQL::Admin::Translate' ) )
+      )
       ? @_
-      : ($MySQL::Admin::Translate::DefaultClass->new, @_);
-}
+      : ( $MySQL::Admin::Translate::DefaultClass->new, @_ );
+} ## end sub getSelf
 
 =head2 see Also
 
@@ -106,5 +105,4 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Lesser General Public License for more details.
 
 =cut
-
 1;
